#[repr(u8)]pub enum Misc0SetClkgateCtrl {
ALLOW_AUTO_GATE = 0,
NO_AUTO_GATE = 1,
}Variants
ALLOW_AUTO_GATE = 0
Allow the logic to automatically gate the clock when the XTAL is powered down.
NO_AUTO_GATE = 1
Prevent the logic from ever gating off the clock.
Implementations