#[repr(u8)]pub enum Misc0TogStopModeConfig {
STOP_MODE_CONFIG_0 = 0,
STOP_MODE_CONFIG_1 = 1,
STOP_MODE_CONFIG_2 = 2,
STOP_MODE_CONFIG_3 = 3,
}Variants
STOP_MODE_CONFIG_0 = 0
All analog except rtc powered down on stop mode assertion. XtalOsc=on, RCOsc=off;
STOP_MODE_CONFIG_1 = 1
Certain analog functions such as certain regulators left up. XtalOsc=on, RCOsc=off;
STOP_MODE_CONFIG_2 = 2
XtalOsc=off, RCOsc=on, Old BG=on, New BG=off.
STOP_MODE_CONFIG_3 = 3
XtalOsc=off, RCOsc=on, Old BG=off, New BG=on.
Implementations